@@ -3,11 +3,11 @@ from pkg_resources import get_distribution, DistributionNotFound
 
 try:
     # Change here if project is renamed and does not equal the package name
-    dist_name = 'aleph-client'
+    dist_name = "aleph-client"
     __version__ = get_distribution(dist_name).version
 except DistributionNotFound:
-    __version__ = 'unknown'
+    __version__ = "unknown"
 finally:
     del get_distribution, DistributionNotFound
 
-from .main import create_post, create_aggregate
\ No newline at end of file
+from .main import create_post, create_aggregate
